Package: `QPtomographer`
========================

.. module:: QPtomographer

The `QPtomographer` package groups the related reliable process tomography
routines described in |paper_arxiv_ref|.

The useful code is concentrated in the two following modules:

  - :py:mod:`QPtomographer.channelspace` (channel-space sampling method)

  - :py:mod:`QPtomographer.bistates` (bipartite states sampling method)

Some additional utilities are provided in the following modules:

  - :py:mod:`QPtomographer.figofmerit` (calculating figures of merit)

  - :py:mod:`QPtomographer.util` (various utilities)

The package version is exposed as follows.

.. rubric:: Package contents:

.. toctree::

    QPtomographer.channelspace
    QPtomographer.bistates
    QPtomographer.figofmerit
    QPtomographer.util
    QPtomographer._members
